@@ -33,6 +33,7 @@ from ola.OlaClient import OlaClient, RDMNack
 from ola.RDMAPI import RDMAPI
 from ola.UID import UID
 
+
 def Usage():
   print(textwrap.dedent("""\
   Usage: ola_rdm_get.py --universe <universe> --uid <uid> <pid>
@@ -51,7 +52,6 @@ def Usage():
 wrapper = None
 
 
-
 class ResponsePrinter(object):
   def __init__(self):
     self.pid_store = PidStore.GetStore()
@@ -112,7 +112,6 @@ class InteractiveModeController(cmd.Cmd):
     self._universe = universe
     self._uid = uid
     self._sub_device = sub_device
-
     self.pid_store = PidStore.GetStore(pid_location)
     self.wrapper = ClientWrapper()
     self.client = self.wrapper.Client()
@@ -180,7 +179,7 @@ class InteractiveModeController(cmd.Cmd):
 
     if sub_device < 0 or sub_device > PidStore.ALL_SUB_DEVICES:
       print('*** Argument must be between 0 and 0x%hx' %
-             PidStore.ALL_SUB_DEVICES)
+            PidStore.ALL_SUB_DEVICES)
       return
     self._sub_device = sub_device
 
@@ -269,7 +268,7 @@ class InteractiveModeController(cmd.Cmd):
 
     # now check if this type of request is supported
     pid_names = sorted([pid.name.lower() for pid in pids
-                 if pid.RequestSupported(request_type)])
+                        if pid.RequestSupported(request_type)])
 
     return pid_names
 
@@ -295,7 +294,6 @@ class InteractiveModeController(cmd.Cmd):
       print('*** Unknown pid %s' % args[0])
       return
 
-    rdm_args = args[1:]
     if not pid.RequestSupported(request_type):
       print('*** PID does not support command')
       return
@@ -419,8 +417,8 @@ def main():
   try:
     opts, args = getopt.getopt(sys.argv[1:], 'd:hilp:u:',
                                ['sub-device=', 'help', 'interactive',
-                                 'list-pids', 'pid-location=', 'uid=',
-                                 'universe='])
+                                'list-pids', 'pid-location=', 'uid=',
+                                'universe='])
   except getopt.GetoptError as err:
     print(str(err))
     Usage()
@@ -457,6 +455,13 @@ def main():
     Usage()
     sys.exit()
 
+  # try to load the PID store so we fail early if we're missing PIDs
+  try:
+    PidStore.GetStore(pid_location)
+  except PidStore.MissingPLASAPIDs as e:
+    print e
+    sys.exit()
+
   controller = InteractiveModeController(universe,
                                          uid,
                                          sub_device,
