@@ -65,6 +65,10 @@ class UnpackException(Error):
   """Raised if we can't unpack the data corectly."""
 
 
+class MissingPLASAPIDs(Error):
+  """Raises if the files did not contain the PLASA PIDs."""
+
+
 class Pid(object):
   """A class that describes everything about a PID."""
   def __init__(self, name, value,
@@ -1215,4 +1219,16 @@ def GetStore(location=None, only_files=()):
         continue
       pid_files.append(os.path.join(location, file_name))
     _pid_store.Load(pid_files)
+
+  REQUIRED_PIDS = [
+      'DEVICE_INFO',
+      'QUEUED_MESSAGE',
+      'SUPPORTED_PARAMETERS'
+  ]
+  for pid in REQUIRED_PIDS:
+    if not _pid_store.GetName(pid):
+      raise MissingPLASAPIDs(
+          'Could not find %s in PID datastore, check the directory contains '
+          'the PLASA PIDs.' % pid)
+
   return _pid_store
