@@ -50,7 +50,7 @@ class StreamRpcChannel(service.RpcChannel):
   SIZE_MASK = 0x0fffffff
   RECEIVE_BUFFER_SIZE = 8192
 
-  def __init__(self, socket, service_impl, close_callback = None):
+  def __init__(self, socket, service_impl, close_callback=None):
     """Create a new StreamRpcChannel.
 
     Args:
@@ -62,9 +62,9 @@ class StreamRpcChannel(service.RpcChannel):
     self._sequence = 0
     self._outstanding_requests = {}
     self._outstanding_responses = {}
-    self._buffer = [] # the received data
-    self._expected_size = None # the size of the message we're receiving
-    self._skip_message = False # skip the current message
+    self._buffer = []  # The received data
+    self._expected_size = None  # The size of the message we're receiving
+    self._skip_message = False  # Skip the current message
     self._close_callback = close_callback
 
   def SocketReady(self):
@@ -245,7 +245,7 @@ class StreamRpcChannel(service.RpcChannel):
 
         if version != self.PROTOCOL_VERSION:
           logging.warning('Protocol mismatch: %d != %d', version,
-              self.PROTOCOL_VERSION)
+                          self.PROTOCOL_VERSION)
           self._skip_message = True
         self._expected_size = size
 
@@ -303,7 +303,6 @@ class StreamRpcChannel(service.RpcChannel):
     callback = lambda x: self.RequestComplete(request, x)
     self._service.CallMethod(method, request.controller, request_pb, callback)
 
-
   def _HandleResponse(self, message):
     """Handle a Response message.
 
